"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_testing_library_1 = require("react-testing-library");
const index_1 = require("../index");
const helpers_1 = require("./helpers");
describe('QueryParamProvider', () => {
    afterEach(react_testing_library_1.cleanup);
    it('works with @reach/router style history', () => {
        const reachHistory = { navigate: jest.fn() };
        const tree = (React.createElement(index_1.QueryParamProvider, { reachHistory: reachHistory },
            React.createElement(index_1.QueryParamContext.Consumer, null, ({ history }) => {
                history.replace(helpers_1.makeMockLocation({ foo: '123' }));
                history.push(helpers_1.makeMockLocation({ bar: 'zzz' }));
                return React.createElement("div", null, "consumed");
            })));
        react_testing_library_1.render(tree);
        expect(reachHistory.navigate).toBeCalledTimes(2);
        expect(reachHistory.navigate.mock.calls[0][0]).toBe('http://localhost/?foo=123');
        expect(reachHistory.navigate.mock.calls[0][1].replace).toBe(true);
        expect(reachHistory.navigate.mock.calls[1][0]).toBe('http://localhost/?bar=zzz');
        expect(reachHistory.navigate.mock.calls[1][1].replace).toBe(false);
    });
    it('works with react-router style history', () => {
        const routeProps = { history: helpers_1.makeMockHistory() };
        const MockRoute = ({ children }) => children(routeProps);
        const tree = (React.createElement(index_1.QueryParamProvider, { ReactRouterRoute: MockRoute },
            React.createElement(index_1.QueryParamContext.Consumer, null, ({ history }) => {
                history.replace(helpers_1.makeMockLocation({ foo: '123' }));
                history.push(helpers_1.makeMockLocation({ bar: 'zzz' }));
                return React.createElement("div", null, "consumed");
            })));
        react_testing_library_1.render(tree);
        expect(routeProps.history.replace).toBeCalledTimes(1);
        expect(routeProps.history.replace.mock.calls[0][0].search).toBe('?foo=123');
        expect(routeProps.history.push).toBeCalledTimes(1);
        expect(routeProps.history.push.mock.calls[0][0].search).toBe('?bar=zzz');
    });
    it('works with window history', () => {
        let windowHistory;
        const tree = (React.createElement(index_1.QueryParamProvider, null,
            React.createElement(index_1.QueryParamContext.Consumer, null, ({ history }) => {
                windowHistory = history;
                history.replace(helpers_1.makeMockLocation({ foo: '123' }));
                history.push(helpers_1.makeMockLocation({ bar: 'zzz' }));
                return React.createElement("div", null, "consumed");
            })));
        react_testing_library_1.render(tree);
        expect(windowHistory.replace).toBeDefined();
        expect(windowHistory.push).toBeDefined();
    });
});
