"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const updateUrlQuery_1 = require("../updateUrlQuery");
const helpers_1 = require("./helpers");
describe('updateUrlQuery', () => {
    it('replaceIn', () => {
        const history = helpers_1.makeMockHistory();
        // test updating existing query param
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({ foo: '521', bar: 'zzz' }), history, 'replaceIn');
        expect(history.push).not.toBeCalled();
        expect(history.replace).toBeCalled();
        expect(helpers_1.calledReplaceQuery(history, 0)).toEqual({
            foo: '123',
            bar: 'zzz',
        });
        // test when no query params
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({}), history, 'replaceIn');
        expect(helpers_1.calledReplaceQuery(history, 1)).toEqual({
            foo: '123',
        });
    });
    it('pushIn', () => {
        const history = helpers_1.makeMockHistory();
        // test updating existing query param
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({ foo: '521', bar: 'zzz' }), history, 'pushIn');
        expect(history.replace).not.toBeCalled();
        expect(history.push).toBeCalled();
        expect(helpers_1.calledPushQuery(history, 0)).toEqual({
            foo: '123',
            bar: 'zzz',
        });
        // test when no query params
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({}), history, 'pushIn');
        expect(helpers_1.calledPushQuery(history, 1)).toEqual({
            foo: '123',
        });
    });
    it('replace', () => {
        const history = helpers_1.makeMockHistory();
        // test updating existing query param
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({ foo: '521', bar: 'zzz' }), history, 'replace');
        expect(history.push).not.toBeCalled();
        expect(history.replace).toBeCalled();
        expect(helpers_1.calledReplaceQuery(history, 0)).toEqual({
            foo: '123',
        });
        // test when no query params
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({}), history, 'replace');
        expect(helpers_1.calledReplaceQuery(history, 1)).toEqual({
            foo: '123',
        });
    });
    it('push', () => {
        const history = helpers_1.makeMockHistory();
        // test updating existing query param
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({ foo: '521', bar: 'zzz' }), history, 'push');
        expect(history.replace).not.toBeCalled();
        expect(history.push).toBeCalled();
        expect(helpers_1.calledPushQuery(history, 0)).toEqual({
            foo: '123',
        });
        // test when no query params
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, helpers_1.makeMockLocation({}), history, 'push');
        expect(helpers_1.calledPushQuery(history, 1)).toEqual({
            foo: '123',
        });
    });
    it('uses query property if available', () => {
        const history = helpers_1.makeMockHistory();
        // test updating existing query param
        updateUrlQuery_1.updateUrlQuery({ foo: '123' }, {
            query: { foo: '521', bar: 'zzz' },
        }, history, 'replaceIn');
        expect(history.push).not.toBeCalled();
        expect(history.replace).toBeCalled();
        // uses query instead of search (sets search to '')
        expect(history.replace.mock.calls[0][0].query).toEqual({
            foo: '123',
            bar: 'zzz',
        });
        expect(history.replace.mock.calls[0][0].search).toBe('');
    });
});
