"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_hooks_testing_library_1 = require("react-hooks-testing-library");
const index_1 = require("../index");
const helpers_1 = require("./helpers");
const params_1 = require("../params");
// helper to setup tests
function setupWrapper(query) {
    const location = helpers_1.makeMockLocation(query);
    const history = helpers_1.makeMockHistory(location);
    const wrapper = ({ children }) => (React.createElement(index_1.QueryParamProvider, { history: history, location: location }, children));
    return { wrapper, history, location };
}
describe('useQueryParam', () => {
    afterEach(react_hooks_testing_library_1.cleanup);
    it('default param type (string, replaceIn)', () => {
        const { wrapper, history } = setupWrapper({ foo: '123', bar: 'xxx' });
        const { result } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParam('foo'), { wrapper });
        const [decodedValue, setter] = result.current;
        expect(decodedValue).toBe('123');
        setter('zzz');
        expect(helpers_1.calledReplaceQuery(history, 0)).toEqual({ foo: 'zzz', bar: 'xxx' });
    });
    it('specific param type and update type', () => {
        const { wrapper, history } = setupWrapper({ foo: '123', bar: 'xxx' });
        const { result } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParam('foo', params_1.NumberParam), {
            wrapper,
        });
        const [decodedValue, setter] = result.current;
        expect(decodedValue).toBe(123);
        setter(999, 'push');
        expect(helpers_1.calledPushQuery(history, 0)).toEqual({ foo: '999' });
    });
    it("doesn't decode more than necessary", () => {
        const { wrapper, history, location } = setupWrapper({ foo: 'a_b_c' });
        const { result, rerender } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParam('foo', params_1.ArrayParam), {
            wrapper,
        });
        const [decodedValue, setter] = result.current;
        expect(decodedValue).toEqual(['a', 'b', 'c']);
        rerender();
        const [decodedValue2, setter2] = result.current;
        expect(decodedValue).toBe(decodedValue2);
        setter2(['d', 'e', 'f'], 'replaceIn');
        rerender();
        const [decodedValue3, setter3] = result.current;
        expect(decodedValue).not.toBe(decodedValue3);
        expect(decodedValue3).toEqual(['d', 'e', 'f']);
        setter3(['d', 'e', 'f'], 'push');
        rerender();
        const [decodedValue4, setter4] = result.current;
        expect(decodedValue3).toBe(decodedValue4);
    });
});
