"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_hooks_testing_library_1 = require("react-hooks-testing-library");
const index_1 = require("../index");
const helpers_1 = require("./helpers");
const params_1 = require("../params");
// helper to setup tests
function setupWrapper(query) {
    const location = helpers_1.makeMockLocation(query);
    const history = helpers_1.makeMockHistory(location);
    const wrapper = ({ children }) => (React.createElement(index_1.QueryParamProvider, { history: history, location: location }, children));
    return { wrapper, history, location };
}
describe('useQueryParams', () => {
    afterEach(react_hooks_testing_library_1.cleanup);
    it('default update type (replaceIn)', () => {
        const { wrapper, history } = setupWrapper({ foo: '123', bar: 'xxx' });
        const { result } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParams({ foo: params_1.StringParam }), {
            wrapper,
        });
        const [decodedQuery, setter] = result.current;
        expect(decodedQuery).toEqual({ foo: '123' });
        setter({ foo: 'zzz' });
        expect(helpers_1.calledReplaceQuery(history, 0)).toEqual({ foo: 'zzz', bar: 'xxx' });
    });
    it('multiple params', () => {
        const { wrapper, history } = setupWrapper({ foo: '123', bar: 'xxx' });
        const { result } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParams({ foo: params_1.NumberParam, bar: params_1.StringParam, baz: params_1.ArrayParam }), {
            wrapper,
        });
        const [decodedQuery, setter] = result.current;
        expect(decodedQuery).toEqual({ foo: 123, bar: 'xxx' });
        setter({ foo: 555, baz: ['a', 'b'] }, 'push');
        expect(helpers_1.calledPushQuery(history, 0)).toEqual({ foo: '555', baz: 'a_b' });
    });
    it('ignores unconfigured parameter', () => {
        const { wrapper, history } = setupWrapper({ foo: '123', bar: 'xxx' });
        const { result } = react_hooks_testing_library_1.renderHook(() => index_1.useQueryParams({ foo: params_1.NumberParam, bar: params_1.StringParam }), {
            wrapper,
        });
        const [decodedQuery, setter] = result.current;
        expect(decodedQuery).toEqual({ foo: 123, bar: 'xxx' });
        setter({ foo: 555, baz: ['a', 'b'] }, 'push');
        expect(helpers_1.calledPushQuery(history, 0)).toEqual({ foo: '555' });
    });
});
